@@ -3,10 +3,10 @@ use LibraryMake;
 
 class Build {
     method build($dir) {
-        shell('perl -e "use v5.18;"')
+        run('perl', '-e', 'use v5.18;')
             or die "\nPerl 5 version requirement not met\n";
 
-        shell('perl -MFilter::Simple -e ""')
+        run('perl', '-MFilter::Simple', '-e', '')
             or die "\nPlease install the Filter::Simple Perl 5 module!\n";
 
         my %vars = get-vars($dir);
