@@ -52,4 +52,20 @@ sub say {
     return 'say';
 }
 
+sub print {
+    return 'print';
+}
+
+sub note {
+    return 'note';
+}
+
+sub put {
+    return 'put';
+}
+
+sub split {
+    return 'split';
+}
+
 1;
